@@ -7,7 +7,7 @@ package MooseX::Types::SVN;
 }
 use strict;
 
-our $VERSION = '0.004';    # VERSION
+our $VERSION = '0.005';    # VERSION
 use Try::Tiny;
 use SVN::Core;
 use SVN::Fs;
@@ -57,7 +57,7 @@ MooseX::Types::SVN - Moose types for the Subversion Perl bindings
 
 =head1 VERSION
 
-version 0.004
+version 0.005
 
 =head1 SYNOPSIS
 
@@ -81,7 +81,7 @@ another.
 
 =head2 SvnRoot
 
-Represents a L<_p_svn_fs_root|SVN::Fs/_p_svn_fs_root>, and can coerce from a
+Represents a L<_p_svn_fs_root|SVN::Fs/_p_svn_fs_root_t>, and can coerce from a
 C<SvnFs> (retrieving the youngest revision root) or a C<SvnTxn> (retrieving
 the transaction root).
 
@@ -92,11 +92,11 @@ C<SvnRepos> by retrieving the repository filesystem object.
 
 =head2 SvnTxn
 
-Represents a L<_p_svn_fs_txn_t|SVN::Fs/_p_svn_txn_t>.
+Represents a L<_p_svn_fs_txn_t|SVN::Fs/_p_svn_fs_txn_t>.
 
 =head2 SvnRepos
 
-Represents a L<_p_svn_repos_t|SVN::Repos/_p_svn_repos_t>, and can coerce from
+Represents a L<_p_svn_repos_t|SVN::Repos>, and can coerce from
 a L<Path::Class::Dir|Path::Class::Dir> object by first trying to open, then
 create a repository at the specified directory location.
 
